\name{splscox-package}
\alias{splscox-package}
\alias{splscox}
\alias{coxfit.spls}
\alias{coxfit.sreg}
\alias{cv.coxfit}

\docType{package}
\title{
Sparse partial least-squares regression for high-throughput survival data analysis
}
\description{
Sparse partial least-squares procedure for survival data to 
allow both sparse variable selection and dimension reduction.
}
\usage{
coxfit.spls(y,d,x,i.idx=NULL, tuning=(1,30,1))	
coxfit.sreg(y,d,x,i.idx=NULL,tuning=(1,30))
cv.coxfit(y,d,x,method="spls",fold=5,tau.vec,w.vec,K.vec)
}

\arguments{

\item{y}{
	n-by-1 vector of observed failure times measured on n samples 
}	

\item{d}{
	n-by-1 vector of event indicators (1=event, 0=censored)
}

\item{x}{
	n-by-p matrix of p covariates measured on same \code{n} samples 
}

\item{i.idx}{Column indices of non-genomic covariates (e.g. sex, age) in covariate matrix, \code{x}. 
The corresponding regression coefficients are not regularized. 
}

\item{tuning}{
	For  \code{coxfit.sreg}, \code{tuning =(tau, w)}. \code{tau} controls the sparsity of regression coefficients and \code{w} determines shape, especially sharpness at origin, of the penalty function. If \code{w}=2, the penalty becomes L1 penalty and if \code{w}>2, the penalty is unbounded at origin. For \code{coxfit.spls}, \code{tuning =(tau, w, K)}.  
 \code{K} is the number of PLS components.
}	
\item{method}{
	Method to fit. The options are "sreg" (use \code{coxfit.sreg}) or "spls"  (use \code{coxfit.spls}). 
	
}
\item{fold}{
The number of folds in cross-validation. Default is 5. 
}
\item{tau.vec}{A vector specifying grid points of the tuning parameter for \code{tau} }
\item{w.vec}{A vector specifying grid points of the tuning parameter for \code{w}}
\item{K.vec}{A vector specifying grid points of the tuning parameter for \code{K}}

}


\details{
\tabular{ll}{
Package: \tab splscox\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2013-04-16\cr
}
The partial least-squares (PLS) method has been adapted to the Cox's proportional hazards model for analyzing high-dimensional survival data. But since latent components constructed in PLS employ all predictors regardless of their relevance, it is difficult to interpret the result.
In this package, we propose a new formulation of the sparse PLS (SPLS) procedure for survival data
to allow both sparse variable selection and
dimension reduction. The 
computing algorithm for SPLS is based on the modified iteratively reweighted PLS algorithm. 
}

\value{
For \code{coxfit.sreg} and \code{coxfit.spls},	
    \item{coef}{Estimates of regression coefficients}
    \item{i.idx}{column index of non-genomic covariates}
    \item{clam0}{Estimates of cumulative baseline hazard}
    \item{times}{Observed failure times}
For \code{cv.coxfit},
	\item{cvmat}{matrix of cross-validated partial likelihood}
	\item{opt}{the optimal tuning parameters which maximize cross-validated partial likelihood}
	\item{L1.opt}{the optimal tuning parameters when L1 penalty is used (\code{w} is fixed at 2)}
}
\author{
Donghwan Lee, Woojoo Lee, Youngjo Lee and Yudi Pawitan

Maintainer: Donghwan Lee <donghwan.lee@ki.se> and Woojoo Lee <lwj221@gmail.com>
}
\references{
Lee, D., Lee, Y., Lee, W. and Pawitan, Y. (2013). 
Sparse partial least-squares regression for high-throughput survival data analysis, submitted for publication.
}

\keyword{ High-dimensional problem, Partial least-squares, Penalized likelihood, Sparsity, Survival analysis}

\examples{

library(MASS)


rho<-0.9;k<-10;n<-100

diag.sigma<-rep(1,10)
p<-200; b.size<-p/10


set.seed(12345)

    
## Generation of survival data (y, d, x)

X<-matrix(0,n,p) 
    
for (i in 1:10){
	sigma_b<-matrix(diag.sigma[i]*rho, b.size, b.size)
    diag(sigma_b)<-rep(diag.sigma[i],b.size)
    rr<-c( ((i-1)*b.size+1):(i*b.size))
    X[,rr]<-mvrnorm(n,mu=rep(0,b.size),Sigma=sigma_b)
}    
    
b.true<-rep(0,p)
a<- -log(1/2)/(k-1)
for (j in 1:b.size){
    b.true[j]<-exp(-a*(j-1))
    b.true[j+b.size]<- -b.true[j]
}

qq<-c(sqrt(b.true[1:b.size]\%*\%sigma_b\%*\%b.true[1:b.size] + b.true[(b.size+1):(2*b.size)]\%*\%sigma_b\%*\%b.true[(b.size+1):(2*b.size)]))
b.true<-b.true/qq
eta.true<-X\%*\%b.true ## linear predictor


St<-rweibull(n, shape=5, scale=(exp(eta.true)^(-1/5)))
Ct<-runif(n, min=0, max=2)
d<-as.numeric(St<Ct)
y<-St*d + Ct*(1-d)
surv.data<-cbind(y,d,X)
surv.data<- surv.data[order(y), ]

y<-surv.data[,1]; d<-surv.data[,2]; x<-surv.data[,-c(1,2)]

## Sparse Cox regression (SREG)

tau.vec<-c(0.05, 0.10, 0.25, 0.50, 1.00, 2.50, 5.00)*n; w.vec<-c(2,5, 10, 20, 30, 50)
# cross-validation
cv.sreg<-cv.coxfit(y,d,x,method="sreg",fold=5,tau.vec=tau.vec, w.vec=w.vec)

sreg.HL<-coxfit.sreg(y,d,x, tuning=cv.sreg$opt,cutoff=4) ## HL
sreg.L1<-coxfit.sreg(y,d,x, tuning=cv.sreg$L1.opt,cutoff=4) ## L1


## Sparse Cox PLS regression (SPLS)

K.vec<-c(1,2,3)

# cross-validation
cv.spls<-cv.coxfit(y,d,x,method="spls",fold=5,tau.vec=tau.vec, w.vec=w.vec, K.vec=K.vec)

spls.HL<-coxfit.spls(y,d,x,tuning=cv.spls$opt,cutoff=4)  ## HL
spls.L1<-coxfit.spls(y,d,x,tuning=cv.spls$L1.opt,cutoff=4)  ## L1


}
